"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_sdk_1 = require("lisk-sdk");
const constants_1 = require("../constants");
const schema_1 = require("../schema");
exports.getLegacyBytes = (publicKey) => lisk_sdk_1.cryptography.getFirstEightBytesReversed(lisk_sdk_1.cryptography.hash(publicKey));
class ReclaimAsset extends lisk_sdk_1.BaseAsset {
    constructor() {
        super(...arguments);
        this.name = 'reclaimLSK';
        this.id = 0;
        this.schema = schema_1.reclaimAssetSchema;
    }
    async apply({ asset, reducerHandler, stateStore, transaction: { senderPublicKey }, }) {
        const encodedUnregisteredAddresses = await stateStore.chain.get(constants_1.CHAIN_STATE_UNREGISTERED_ADDRESSES);
        if (!encodedUnregisteredAddresses) {
            throw new Error('Chain state does not contain any unregistered addresses.');
        }
        const { unregisteredAddresses } = lisk_sdk_1.codec.decode(schema_1.unregisteredAddressesSchema, encodedUnregisteredAddresses);
        const legacyAddress = exports.getLegacyBytes(senderPublicKey);
        const addressWithoutPublickey = unregisteredAddresses.find(a => a.address.equals(legacyAddress));
        if (!addressWithoutPublickey) {
            throw new Error('Legacy address corresponding to sender publickey was not found in the genesis account state.');
        }
        if (asset.amount !== addressWithoutPublickey.balance) {
            throw new Error(`Invalid amount:${asset.amount.toString()} claimed by the sender: ${addressWithoutPublickey.address.toString('hex')}.`);
        }
        const newAddress = lisk_sdk_1.cryptography.getAddressFromPublicKey(senderPublicKey);
        const { address } = await stateStore.account.get(newAddress);
        await reducerHandler.invoke('token:credit', {
            address,
            amount: addressWithoutPublickey.balance,
        });
        const excludedClaimedAccount = unregisteredAddresses.filter(account => !account.address.equals(addressWithoutPublickey.address));
        stateStore.chain.set(constants_1.CHAIN_STATE_UNREGISTERED_ADDRESSES, lisk_sdk_1.codec.encode(schema_1.unregisteredAddressesSchema, {
            unregisteredAddresses: excludedClaimedAccount,
        }));
    }
}
exports.ReclaimAsset = ReclaimAsset;
//# sourceMappingURL=reclaim_asset.js.map